//Calendar implementation for the HTWK Leipzig timetable. Evaluation and display of the individual dates in iCal format.
//Copyright (C) 2024 HTWKalender support@htwkalender.de

//This program is free software: you can redistribute it and/or modify
//it under the terms of the GNU Affero General Public License as published by
//the Free Software Foundation, either version 3 of the License, or
//(at your option) any later version.

//This program is distributed in the hope that it will be useful,
//but WITHOUT ANY WARRANTY; without even the implied warranty of
//MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//GNU Affero General Public License for more details.

//You should have received a copy of the GNU Affero General Public License
//along with this program.  If not, see <https://www.gnu.org/licenses/>.

import { ref } from "vue";
import { PrimeVueChangeTheme } from "primevue/config";
import { EmitFn } from "primevue/ts-helpers";
import settingsStore from "@/store/settingsStore.ts";

const darkTheme = ref("lara-dark-blue"),
  lightTheme = ref("lara-light-blue");

export type SettingsStore = typeof settingsStore;

export function toggleTheme(
  store: SettingsStore,
  primeVue: { changeTheme: PrimeVueChangeTheme },
  emit: EmitFn<"dark-mode-toggled"[]>,
): void {
  store().setDarkMode(!store().isDark);
  setTheme(store, primeVue, emit);
}

export function setTheme(
  store: SettingsStore,
  { changeTheme }: { changeTheme: PrimeVueChangeTheme },
  emit: EmitFn<"dark-mode-toggled"[]>,
) {
  const isDark = ref(store().isDark);
  const newTheme = isDark.value ? darkTheme.value : lightTheme.value,
    oldTheme = isDark.value ? lightTheme.value : darkTheme.value;
  changeTheme(oldTheme, newTheme, "theme-link", () => {});
  emit("dark-mode-toggled", isDark.value);
}
